@@ -1,5 +1,7 @@
-import  click
-class Command(object, click.Command):
+import click
+
+
+class Command(object):
     def get_help_text(self):
         raise NotImplementedError("Please Implement this method")
 
@@ -8,3 +10,9 @@ class Command(object, click.Command):
 
     def callback(self):
         pass
+
+    def get_options(self):
+        raise NotImplementedError("Please Implement this method")
+
+    def get_arguments(self):
+        raise NotImplementedError("Please Implement this method")
