@@ -1,6 +1,7 @@
 import click
 import pyfiglet
 
+
 from .. import profile_configurator, login_processor
 from ..constants.constants import Formats, Export_Formats
 from ..processors.addons.addons import Addons
@@ -14,7 +15,6 @@ from ..processors.credit_notes.credit_note import CreditNote
 from ..processors.customer.customer import Customer
 from ..processors.events.events import Event
 from ..processors.exports.export import Export
-from ..processors.gifts.gifts import Gift
 from ..processors.hosted_pages.hosted_pages import HostedPage
 from ..processors.invoices.invoice import Invoice
 from ..processors.order.order import Order
@@ -25,7 +25,9 @@ from ..processors.quotes.quote import Quote
 from ..processors.subs.subscriptions import Subscription
 from ..processors.transactions.transaction import Transaction
 from ..processors.unbilled_chrages.unbilled_charge import UnbilledCharge
+from ..util import version_util
 from ..util.multiple_columns import MultipleColumns
+from ..util.printer import custom_print
 
 
 def safe_entry_point():
@@ -47,7 +49,6 @@ def get_cmd_help():
 
 
 @click.group(help=get_cmd_help())
-@click.version_option("0.0.7 - python: 3.9")
 @click.pass_context
 def entry_point(ctx):
     """unleash the power of chargebee apis from your command prompt.
@@ -121,7 +122,7 @@ def login(ctx, profile):
 @click.option('--export-filename', "-efn", help='name of exported file', type=str)
 @click.option('--export-path', "-ep", help='path where file to be exported', type=click.Path(exists=True))
 def plan(ctx, id, operation, columns, format, name, invoice_name, price, export_filename, export_format, export_path):
-    Plan(export_format=export_format, export_path=export_path, file_name=export_filename) \
+    Plan(export_format=export_format, export_path=export_path, file_name=export_filename, response_format=format ) \
         .validate_param(columns) \
         .process(None, operation, payload=None, resource_id=id) \
         .format(format, operation) \
@@ -132,7 +133,7 @@ def plan(ctx, id, operation, columns, format, name, invoice_name, price, export_
 # plan end
 @entry_point.resultcallback()
 def process_result(result):
-    print("\n.................................end.................................")
+    custom_print("\n.................................end.................................")
     return result
 
 
@@ -198,10 +199,11 @@ def coupon(ctx, id, operation, columns, format, export_filename, export_format,
 @click.option('--export-filename', "-efn", help='name of exported file', type=str)
 @click.option('--export-path', "-ep", help='path where file to be exported', type=click.Path(exists=True))
 def customer(ctx, id, operation, columns, format, export_filename, export_format, export_path):
-    Customer() \
+    Customer(export_format=export_format, export_path=export_path, file_name=export_filename, response_format=format) \
         .validate_param(columns) \
         .process(None, operation, payload=None, resource_id=id) \
-        .format(format, operation)
+        .format(format, operation) \
+        .export_data()
 
 
 # coupons end
@@ -379,12 +381,8 @@ def order(ctx, id, operation, columns, format, export_filename, export_format, e
 @click.option("--format", "-f", required=False,
               help="this allows user to format the output in json or table format..", default=Formats.TABLE.name)
 @click.argument('columns', nargs=-1)
-@click.option('--export-format', "-ef", help='data to be imported in [csv / excel / html',
-              default=Export_Formats.CSV.value, type=str)
-@click.option('--export-filename', "-efn", help='name of exported file', type=str)
-@click.option('--export-path', "-ep", help='path where file to be exported', type=click.Path(exists=True))
-def gift(ctx, id, operation, columns, format, export_filename, export_format, export_path):
-    Gift() \
+def order(ctx, id, operation, columns, format):
+    Order() \
         .validate_param(columns) \
         .process(None, operation, payload=None, resource_id=id) \
         .format(format, operation)
@@ -399,11 +397,7 @@ def gift(ctx, id, operation, columns, format, export_filename, export_format, ex
 @click.option("--format", "-f", required=False,
               help="this allows user to format the output in json or table format..", default=Formats.TABLE.name)
 @click.argument('columns', nargs=-1)
-@click.option('--export-format', "-ef", help='data to be imported in [csv / excel / html',
-              default=Export_Formats.CSV.value, type=str)
-@click.option('--export-filename', "-efn", help='name of exported file', type=str)
-@click.option('--export-path', "-ep", help='path where file to be exported', type=click.Path(exists=True))
-def txn(ctx, id, operation, columns, format, export_filename, export_format, export_path):
+def txn(ctx, id, operation, columns, format):
     Transaction() \
         .validate_param(columns) \
         .process(None, operation, payload=None, resource_id=id) \
@@ -419,11 +413,7 @@ def txn(ctx, id, operation, columns, format, export_filename, export_format, exp
 @click.option("--format", "-f", required=False,
               help="this allows user to format the output in json or table format..", default=Formats.TABLE.name)
 @click.argument('columns', nargs=-1)
-@click.option('--export-format', "-ef", help='data to be imported in [csv / excel / html',
-              default=Export_Formats.CSV.value, type=str)
-@click.option('--export-filename', "-efn", help='name of exported file', type=str)
-@click.option('--export-path', "-ep", help='path where file to be exported', type=click.Path(exists=True))
-def hosted_pages(ctx, id, operation, columns, format, export_filename, export_format, export_path):
+def hosted_pages(ctx, id, operation, columns, format):
     HostedPage() \
         .validate_param(columns) \
         .process(None, operation, payload=None, resource_id=id) \
@@ -439,11 +429,7 @@ def hosted_pages(ctx, id, operation, columns, format, export_filename, export_fo
 @click.option("--format", "-f", required=False,
               help="this allows user to format the output in json or table format..", default=Formats.TABLE.name)
 @click.argument('columns', nargs=-1)
-@click.option('--export-format', "-ef", help='data to be imported in [csv / excel / html',
-              default=Export_Formats.CSV.value, type=str)
-@click.option('--export-filename', "-efn", help='name of exported file', type=str)
-@click.option('--export-path', "-ep", help='path where file to be exported', type=click.Path(exists=True))
-def quote(ctx, id, operation, columns, format, export_filename, export_format, export_path):
+def quote(ctx, id, operation, columns, format):
     Quote() \
         .validate_param(columns) \
         .process(None, operation, payload=None, resource_id=id) \
@@ -459,11 +445,7 @@ def quote(ctx, id, operation, columns, format, export_filename, export_format, e
 @click.option("--format", "-f", required=False,
               help="this allows user to format the output in json or table format..", default=Formats.TABLE.name)
 @click.argument('columns', nargs=-1)
-@click.option('--export-format', "-ef", help='data to be imported in [csv / excel / html',
-              default=Export_Formats.CSV.value, type=str)
-@click.option('--export-filename', "-efn", help='name of exported file', type=str)
-@click.option('--export-path', "-ep", help='path where file to be exported', type=click.Path(exists=True))
-def coupon_set(ctx, id, operation, columns, format, export_filename, export_format, export_path):
+def coupon_set(ctx, id, operation, columns, format):
     CouponSet() \
         .validate_param(columns) \
         .process(None, operation, payload=None, resource_id=id) \
@@ -479,11 +461,7 @@ def coupon_set(ctx, id, operation, columns, format, export_filename, export_form
 @click.option("--format", "-f", required=False,
               help="this allows user to format the output in json or table format..", default=Formats.TABLE.name)
 @click.argument('columns', nargs=-1)
-@click.option('--export-format', "-ef", help='data to be imported in [csv / excel / html',
-              default=Export_Formats.CSV.value, type=str)
-@click.option('--export-filename', "-efn", help='name of exported file', type=str)
-@click.option('--export-path', "-ep", help='path where file to be exported', type=click.Path(exists=True))
-def coupon_code(ctx, id, operation, columns, format, export_filename, export_format, export_path):
+def coupon_code(ctx, id, operation, columns, format):
     """ endpoint to perform operation on coupon resources."""
     if operation == 'archive':
         operation = 'delete'
@@ -503,11 +481,7 @@ def coupon_code(ctx, id, operation, columns, format, export_filename, export_for
 @click.option("--format", "-f", required=False,
               help="this allows user to format the output in json or table format..", default=Formats.TABLE.name)
 @click.argument('columns', nargs=-1)
-@click.option('--export-format', "-ef", help='data to be imported in [csv / excel / html',
-              default=Export_Formats.CSV.value, type=str)
-@click.option('--export-filename', "-efn", help='name of exported file', type=str)
-@click.option('--export-path', "-ep", help='path where file to be exported', type=click.Path(exists=True))
-def address(ctx, id, operation, columns, format, export_filename, export_format, export_path):
+def address(ctx, id, operation, columns, format):
     Address() \
         .validate_param(columns) \
         .process(None, operation, payload=None, resource_id=id) \
@@ -523,11 +497,7 @@ def address(ctx, id, operation, columns, format, export_filename, export_format,
 @click.option("--format", "-f", required=False,
               help="this allows user to format the output in json or table format..", default=Formats.TABLE.name)
 @click.argument('columns', nargs=-1)
-@click.option('--export-format', "-ef", help='data to be imported in [csv / excel / html',
-              default=Export_Formats.CSV.value, type=str)
-@click.option('--export-filename', "-efn", help='name of exported file', type=str)
-@click.option('--export-path', "-ep", help='path where file to be exported', type=click.Path(exists=True))
-def event(ctx, id, operation, columns, format, export_filename, export_format, export_path):
+def event(ctx, id, operation, columns, format):
     Event() \
         .validate_param(columns) \
         .process(None, operation, payload=None, resource_id=id) \
@@ -543,11 +513,7 @@ def event(ctx, id, operation, columns, format, export_filename, export_format, e
 @click.option("--format", "-f", required=False,
               help="this allows user to format the output in json or table format..", default=Formats.TABLE.name)
 @click.argument('columns', nargs=-1)
-@click.option('--export-format', "-ef", help='data to be imported in [csv / excel / html',
-              default=Export_Formats.CSV.value, type=str)
-@click.option('--export-filename', "-efn", help='name of exported file', type=str)
-@click.option('--export-path', "-ep", help='path where file to be exported', type=click.Path(exists=True))
-def comment(ctx, id, operation, columns, format, export_filename, export_format, export_path):
+def comment(ctx, id, operation, columns, format):
     Comment() \
         .validate_param(columns) \
         .process(None, operation, payload=None, resource_id=id) \
