@@ -29,3 +29,15 @@ class Export_Formats_Extensions(enum.Enum):
     CSV = '.csv'
     EXCEL = '.xlsx'
     HTML = '.html'
+
+
+ERROR_HEADER = ["message",
+                "type",
+                "api_error_code",
+                "error_code",
+                "error_msg",
+                "http_status_code"
+                ]
+
+
+
