@@ -1,4 +1,5 @@
 from chargebeecli.constants.constants import ApiOperation
+from chargebeecli.constants.error_messages import OPERATION_NOT_SUPPORTED
 
 
 class Processor(object):
@@ -16,7 +17,7 @@ class Processor(object):
         elif operation ==  ApiOperation.LIST.value:
             self.response = self.list(ctx=ctx)
         else:
-            print('operation is not supported..')
+            print(OPERATION_NOT_SUPPORTED)
             exit()
         return self
 
