@@ -1,6 +1,5 @@
 from chargebeecli.client.actionsImpl import ActionsImpl
 from chargebeecli.export.Exporter import Exporter
-from chargebeecli.printer import Printer
 from chargebeecli.processor import Processor
 from chargebeecli.response_formatter import ResponseFormatter
 from chargebeecli.validator import Validator
@@ -8,7 +7,7 @@ from chargebeecli.validator import Validator
 API_URI = '/api/v2/addons'
 
 
-class Addons(Processor, Validator, ResponseFormatter, Printer, Exporter):
+class Addons(Processor, Validator, ResponseFormatter, Exporter):
     __action_processor = ActionsImpl()
 
     def __init__(self,export_format=None, export_path=None, file_name=None):
