@@ -1,5 +1,4 @@
 from chargebeecli.client.actionsImpl import ActionsImpl
-from chargebeecli.printer import Printer
 from chargebeecli.processor import Processor
 from chargebeecli.response_formatter import ResponseFormatter
 from chargebeecli.validator import Validator
@@ -7,7 +6,7 @@ from chargebeecli.validator import Validator
 API_URI = '/api/v2/exports'
 
 
-class Export(Processor, Validator, ResponseFormatter, Printer):
+class Export(Processor, Validator, ResponseFormatter):
     __action_processor = ActionsImpl()
 
     def __init__(self):
