@@ -1,6 +1,5 @@
 from chargebeecli.client.actionsImpl import ActionsImpl
 from chargebeecli.export.Exporter import Exporter
-from chargebeecli.printer import Printer
 from chargebeecli.processor import Processor
 from chargebeecli.response_formatter import ResponseFormatter
 from chargebeecli.validator import Validator
@@ -8,11 +7,15 @@ from chargebeecli.validator import Validator
 API_URI = '/api/v2/quotes'
 
 
-class Quote(Processor, Validator, ResponseFormatter, Printer, Exporter):
+class Quote(Processor, Validator, ResponseFormatter, Exporter):
     __action_processor = ActionsImpl()
 
-    def __init__(self):
+    def __init__(self, export_format=None, export_path=None, file_name=None):
         self.headers = self.get_api_header()
+        self.export_format = export_format
+        self.export_path = export_path
+        self.file_name = file_name
+        self.tables = None
 
     def validate_param(self, __input_columns):
         self.headers = super().validate_param(__input_columns, self.headers)
