@@ -1,6 +1,5 @@
 from chargebeecli.client.actionsImpl import ActionsImpl
 from chargebeecli.export.Exporter import Exporter
-from chargebeecli.printer import Printer
 from chargebeecli.processor import Processor
 from chargebeecli.processors.customer.subscription_customer import SubscriptionCustomer
 from chargebeecli.response_formatter import ResponseFormatter
@@ -9,10 +8,14 @@ from chargebeecli.validator import Validator
 API_URI = '/api/v2/subscriptions'
 
 
-class Subscription(Processor, Validator, ResponseFormatter, Printer, Exporter):
+class Subscription(Processor, Validator, ResponseFormatter, Exporter):
     __action_processor = ActionsImpl()
 
-    def __init__(self, columns, columns_customer, operation):
+    def __init__(self, columns, columns_customer, operation,export_format=None, export_path=None, file_name=None):
+        self.export_format = export_format
+        self.export_path = export_path
+        self.file_name = file_name
+        self.tables = None
         self.__columns = columns
         self.__operation = operation
         self.headers = self.get_api_header()
