@@ -3,17 +3,10 @@ import json
 import click
 from tabulate import tabulate
 
-from chargebeecli.constants.constants import Formats
+from chargebeecli.constants.constants import Formats, ERROR_HEADER
 
 
 class ResponseFormatter(object):
-    __ERROR_HEADER = ["message",
-                      "type",
-                      "api_error_code",
-                      "error_code",
-                      "error_msg",
-                      "http_status_code"
-                      ]
 
     def format(self, __format, __operation):
         raise NotImplementedError("Please Implement this method")
@@ -21,8 +14,7 @@ class ResponseFormatter(object):
     def format(self, __response, __format, __operation, __headers, __resource_type, __list_key='list'):
         if __response.status_code != 200:
             if __format.lower() != Formats.JSON.value.lower():
-                self.__create_table(__response, __format, __operation, self.__ERROR_HEADER, None, None)
-                return self
+                return self.__create_table(__response, __format, __operation, ERROR_HEADER, None, None)
             click.echo(click.style(__response.content.decode('utf-8'), fg="red"))
             return self
 
