@@ -1,3 +1,6 @@
+from chargebeecli.util.printer import custom_print_error
+
+
 class Validator(object):
 
     def validate_param(self, __input_columns):
@@ -7,17 +10,16 @@ class Validator(object):
         if __input_columns is not None and len(__input_columns) > 0:
             for column in __input_columns:
                 if column not in headers:
-                    print(f"Unknown column :{column}")
+                    custom_print_error(f"Unknown column :{column}")
                     exit()
             headers = __input_columns
         return headers
 
-
     def validate_ids(self, __input_columns, headers):
         if __input_columns is not None and len(__input_columns) > 0:
             for column in __input_columns:
                 if column not in headers:
-                    print(f"Unknown column :{column}")
+                    custom_print_error(f"Unknown column :{column}")
                     exit()
             headers = __input_columns
         return headers
